@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2007-2021 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2007-2022 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -10,20 +10,12 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDir>
+#include <QFileInfo>
+#include <QSettings>
 
 int main(int argc, char** argv)
 {
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-#if !defined(Q_OS_MAC)
-	if (!qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO")
-			&& !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR")
-			&& !qEnvironmentVariableIsSet("QT_SCALE_FACTOR")
-			&& !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS")) {
-		QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-	}
-#endif
-	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
 	QApplication app(argc, argv);
 	app.setApplicationName("CuteMaze");
 	app.setApplicationVersion(VERSIONSTR);
@@ -35,17 +27,37 @@ int main(int argc, char** argv)
 	app.setDesktopFileName("cutemaze");
 #endif
 
-	LocaleDialog::loadTranslator("cutemaze_");
+	// Find application data
+	const QString appdir = app.applicationDirPath();
+	const QString datadir = QDir::cleanPath(appdir + "/" + CUTEMAZE_DATADIR);
 
-	ScoresDialog::migrate();
+	// Handle portability
+#ifdef Q_OS_MAC
+	const QFileInfo portable(appdir + "/../../../Data");
+#else
+	const QFileInfo portable(appdir + "/Data");
+#endif
+	if (portable.exists() && portable.isWritable()) {
+		QSettings::setDefaultFormat(QSettings::IniFormat);
+		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, portable.absoluteFilePath() + "/Settings");
+	}
 
+	// Load application language
+	LocaleDialog::loadTranslator("cutemaze_", datadir);
+
+	// Handle commandline
 	QCommandLineParser parser;
 	parser.setApplicationDescription(Window::tr("A top-down maze game"));
 	parser.addHelpOption();
 	parser.addVersionOption();
 	parser.process(app);
 
+	// Convert old scores to new format
+	ScoresDialog::migrate();
+
+	// Create main window
 	Window window;
 	window.show();
+
 	return app.exec();
 }
